@@ -1,14 +1,15 @@
 # flake8: noqa
 
-from .token import *
-from .utils import *
-from .secret_registry import *
-from .endpoint_registry import *
-from .token_network_registry import *
-from .token_network import *
-from .monitoring_service import *
+from .base import *
 from .channel import *
-from .test_contracts import *
 from .contracts import *
-from .contract_manager import *
-from .raiden_service_bundle import *
+from .deposit_fixtures import *
+from .monitoring_service import *
+from .one_to_n import *
+from .secret_registry import *
+from .service_registry_fixtures import *
+from .test_contracts import *
+from .token import *
+from .token_network_fixtures import *
+from .token_network_registry import *
+from .user_deposit import *
